import { HttpService } from './http';
import { Injectable } from '@angular/core';
import { Router } from '@angular/router';
import { NzMessageService } from 'ng-zorro-antd';
import { environment } from '../../environments/environment';
import { TranslateService } from '@ngx-translate/core';

@Injectable()
export class ApiService {
  constructor(private http: HttpService, private router: Router,
              private message: NzMessageService, private translate: TranslateService) {
  }

  tokenLoseflag = 0;
  public url = environment.baseUrl;

  public imgUrl = environment.imgUrl; // 前端地址

  public homePage = {
    homePage: (data) => this.trans('post', '/homePage/homePage', data)
  };

  public deviceConfig = {
    addTopicConfig: (data) => this.trans('post', '/deviceConfig/addTopicConfig', data),
    delTopicConfig: (data) => this.trans('post', '/deviceConfig/delTopicConfig', data),
    getAll: (data) => this.trans('post', '/deviceConfig/getAll', data),
  };

  public analysis = {
    getCuttingMachine: (data) => this.trans('get', '/analysis/getCuttingMachine', data),
    getCuttingMachineDetail: (data) => this.trans('post', '/analysis/getCuttingMachineDetail', data),
    getCuttingMachineDetailForAlarm: (data) => this.trans('post', '/analysis/getCuttingMachineDetailForAlarm', data),
    getCuttingMachineDetailForData: (data) => this.trans('post', '/analysis/getCuttingMachineDetailForData', data),
    getCuttingMachineDetailForAlarmDetail: (data) => this.trans('post', '/analysis/getCuttingMachineDetailForAlarmDetail', data),
    getCuttingMachineDetailForDisposeAlarm: (data) => this.trans('post', '/analysis/getCuttingMachineDetailForDisposeAlarm', data),
    getCuttingMachineDetailForKnife: (data) => this.trans('post', '/analysis/getCuttingMachineDetailForKnife', data),
    getCuttingMachineForLike: (data) => this.trans('post', '/analysis/getCuttingMachineForLike', data),
    getMachineRoom: (data) => this.trans('get', '/analysis/getMachineRoom', data),
    getMachineRoomAlarm: (data) => this.trans('post', '/analysis/getMachineRoomAlarm', data),
    getMachineRoomAlarmDetail: (data) => this.trans('post', '/analysis/getMachineRoomAlarmDetail', data),
    getMachineRoomDetail: (data) => this.trans('post', '/analysis/getMachineRoomDetail', data),
    getMachineRoomForLike: (data) => this.trans('post', '/analysis/getMachineRoomForLike', data),
  };

  public data = {
    getCISS: (data) => this.trans('post', '/data/getCISS', data),
    getCISSData: (data) => this.trans('get', '/data/getCISSData', data),
    getCISSHistoryData: (data) => this.trans('post', '/data/getCISSHistoryData', data),
    getCISSNum: (data) => this.trans('post', '/data/getCISSNum', data),
    getXDK: (data) => this.trans('post', '/data/getXDK', data),
    getXDKData: (data) => this.trans('get', '/data/getXDKData', data),
    getXDKHistoryData: (data) => this.trans('post', '/data/getXDKHistoryData', data),
    getCISSDataByTerm: (data) => this.trans('post', '/data/getCISSDataByTerm', data),
    getXDKDataByTerm: (data) => this.trans('post', '/data/getXDKDataByTerm', data),
    getAlarmData: (data) => this.trans('post', '/getAlarmData', data),
    getData: (data) => this.trans('post', '/getData', data)
  };

  public dataComparison = {
    getComparisonForKeepCiss: (data) => this.trans('post', '/dataComparison/getComparisonForKeepCiss', data),
    getDataComparisonForKeepCiss: (data) => this.trans('post', '/dataComparison/getDataComparisonForKeepCiss', data),
    getDataComparisonForStepCiss: (data) => this.trans('post', '/dataComparison/getDataComparisonForStepCiss', data),
    getDataComparisonForXDK: (data) => this.trans('post', '/dataComparison/getDataComparisonForXDK', data),
  };

  public download = {
    downloadCissData: (data) => this.trans('post', '/download/downloadCissData', data)
  };

  public deviceType = {
    addDeviceType: (data) => this.trans('post', '/deviceType/addDeviceType', data),
    deleteDeviceType: (data) => this.trans('post', '/deviceType/deleteDeviceType', data),
    getAll: (data) => this.trans('get', '/deviceType/getAll', data),
    getByDeviceTypeForLike: (data) => this.trans('post', '/deviceType/getByDeviceTypeForLike', data),
    updateDeviceType: (data) => this.trans('post', '/deviceType/updateDeviceType', data),
  };

  public deviceModel = {
    addDeviceModel: (data) => this.trans('post', '/deviceModel/addDeviceModel', data),
    getAll: (data) => this.trans('get', '/deviceModel/getAll', data),
    deleteDeviceModel: (data) => this.trans('post', '/deviceModel/deleteDeviceModel', data),
    getByDeviceModelForLike: (data) => this.trans('post', '/deviceModel/getByDeviceModelForLike', data),
    updateDeviceModel: (data) => this.trans('post', '/deviceModel/updateDeviceModel', data),
  };

  public alarm = {
    addAlarm: (data) => this.trans('post', '/alarm/addAlarm', data),
    deleteAlarm: (data) => this.trans('post', '/alarm/deleteAlarm', data),
    getAll: (data) => this.trans('get', '/alarm/getAll', data),
    getByAlarmNameForLike: (data) => this.trans('post', '/alarm/getByAlarmNameForLike', data),
    updateAlarm: (data) => this.trans('post', '/alarm/updateAlarm', data),
  };

  public alarmLog = {
    addAlarmLog: (data) => this.trans('post', '/alarmLog/addAlarmLog', data),
    disposeAlarm: (data) => this.trans('post', '/alarmLog/disposeAlarm', data),
    downloadExcel: (data) => this.trans('post', '/alarmLog/downloadExcel', data),
    getAll: (page, rows, data) => this.trans('get', '/alarmLog/getAll?page=' + page + '&rows=' + rows, data),
    getForTerm: (page, rows, data) => this.trans('post', '/alarmLog/getForTerm?page=' + page + '&rows=' + rows, data),
    updateFault: (data) => this.trans('post', '/alarmLog/updateFault', data),
  };

  public area = {
    getAll: (data) => this.trans('get', '/getAll', data),
    getByCity: (data) => this.trans('post', '/getByCity', data),
  };

  public factory = {
    addFactory: (data) => this.trans('post', '/factory/addFactory', data),
    addFactoryDepartment: (data) => this.trans('post', '/factory/addFactoryDepartment', data),
    addFactoryLine: (data) => this.trans('post', '/factory/addFactoryLine', data),
    deleteFactory: (data) => this.trans('post', '/factory/deleteFactory', data),
    getAll: (data) => this.trans('get', '/factory/getAll', data),
    getAllForDepartment: (data) => this.trans('get', '/factory/getAllForDepartment', data),
    getAllForFactoryArea: (data) => this.trans('get', '/factory/getAllForFactoryArea', data),
    getAllForFactoryLine: (data) => this.trans('get', '/factory/getAllForFactoryLine', data),
    getDepartmentByFactoryNameForLike: (data) => this.trans('post', '/factory/getDepartmentByFactoryNameForLike', data),
    getFactoryAreaByFactoryNameForLike: (data) => this.trans('post', '/factory/getFactoryAreaByFactoryNameForLike', data),
    getFactoryLineByFactoryNameForLike: (data) => this.trans('post', '/factory/getFactoryLineByFactoryNameForLike', data),
    updateFactoryArea: (data) => this.trans('post', '/factory/updateFactoryArea', data),
    updateFactoryLine: (data) => this.trans('post', '/factory/updateFactoryLine', data),
  };

  public operationLog = {
    downloadExcel: (data) => this.trans('post', '/operationLog/downloadExcel', data),
    getAll: (page, rows, data) => this.trans('get', '/operationLog/getAll?page=' + page + '&rows=' + rows, data),
    getByTerm: (page, rows, data) => this.trans('post', '/operationLog/getByTerm?page=' + page + '&rows=' + rows, data),
  };

  public gateway = {
    addGateway: (data) => this.trans('post', '/gateway/addGateway', data),
    allocationGateway: (data) => this.trans('post', '/gateway/allocationGateway', data),
    batchAddGateway: (data) => this.trans('post', '/gateway/batchAddGateway', data),
    batchDeleteGateway: (data) => this.trans('post', '/gateway/batchDeleteGateway', data),
    deleteGateway: (data) => this.trans('post', '/gateway/deleteGateway', data),
    deployGateway: (data) => this.trans('post', '/gateway/deployGateway', data),
    disonnectGateway: (data) => this.trans('post', '/gateway/disonnectGateway', data),
    getAll: (data) => this.trans('get', '/gateway/getAll', data),
    getAllForLike: (data) => this.trans('post', '/gateway/getAllForLike', data),
    updateGateway: (data) => this.trans('post', '/gateway/updateGateway', data),
  };

  public login = {
    dologin: (data) => this.trans('post', '/login/dologin', data),
    logout: (data) => this.trans('get', '/login/logout', data),
  };

  public loginlog = {
    getAll: (page, rows, data) => this.trans('get', '/loginlog/getAll?page=' + page + '&rows=' + rows, data),
    getByTime: (page, rows, data) => this.trans('post', '/loginlog/getByTime?page=' + page + '&rows=' + rows, data),
  };

  public monitoringPoint = {
    getByFactoryAreaNo: (data) => this.trans('post', '/monitoringPoint/getByFactoryAreaNo', data),
    addMonitoringPoint: (data) => this.trans('post', '/monitoringPoint/addMonitoringPoint', data),
    deleteMonitoringPoint: (data) => this.trans('post', '/monitoringPoint/deleteMonitoringPoint', data),
    geByMonitoringPointNameForLike: (data) => this.trans('post', '/monitoringPoint/geByMonitoringPointNameForLike', data),
    getAll: (data) => this.trans('get', '/monitoringPoint/getAll', data),
    getByFactoryNo: (data) => this.trans('post', '/monitoringPoint/getByFactoryNo', data),
    updateMonitoringPoint: (data) => this.trans('post', '/monitoringPoint/updateMonitoringPoint', data),
  };

  public monitoringPointType = {
    addMonitoringPointType: (data) => this.trans('post', '/monitoringPointType/addMonitoringPointType', data),
    deleteMonitoringPointType: (data) => this.trans('post', '/monitoringPointType/deleteMonitoringPointType', data),
    getAll: (data) => this.trans('get', '/monitoringPointType/getAll', data),
    getByMonitoringPointTypeForLike: (data) => this.trans('post', '/monitoringPointType/getByMonitoringPointTypeForLike', data),
    updateMonitoringPointType: (data) => this.trans('post', '/monitoringPointType/updateMonitoringPointType', data),
  };

  public permission = {
    getAll: (data) => this.trans('get', '/permission/getAll', data),
    getPermissionByRoleNo: (data) => this.trans('post', '/permission/getPermissionByRoleNo', data),
  };

  public sensor = {
    addSensor: (data) => this.trans('post', '/sensor/addSensor', data),
    batchAddSensor: (data) => this.trans('post', '/sensor/batchAddSensor', data),
    batchDeleteSensor: (data) => this.trans('post', '/sensor/batchDeleteSensor', data),
    bindSensor: (data) => this.trans('post', '/sensor/bindSensor', data),
    bindSensorAndMonitoringPoint: (data) => this.trans('post', '/sensor/bindSensorAndMonitoringPoint', data),
    deleteSensor: (data) => this.trans('post', '/sensor/deleteSensor', data),
    getAll: (data) => this.trans('get', '/sensor/getAll', data),
    getByFreeAndBindGateway: (data) => this.trans('get', '/sensor/getByFreeAndBindGateway', data),
    getByMonitoringPoint: (data) => this.trans('post', '/sensor/getByMonitoringPoint', data),
    getByFreeForType: (data) => this.trans('post', '/sensor/getByFreeForType', data),
    getUnFreeByType: (data) => this.trans('post', '/sensor/getUnFreeByType', data),
    getByTerm: (data) => this.trans('post', '/sensor/getByTerm', data),
    unBindSensor: (data) => this.trans('post', '/sensor/unBindSensor', data),
    getUnFreeByCissType: (data) => this.trans('post', '/sensor/getUnFreeByCissType', data),
    unbindSensorAndMonitoringPoint: (data) => this.trans('post', '/sensor/unbindSensorAndMonitoringPoint', data),
    updateSensor: (data) => this.trans('post', '/sensor/updateSensor', data),
    updateSensorFactory: (data) => this.trans('post', '/sensor/updateSensorFactory', data)
  };

  public user = {
    addUser: (data) => this.trans('post', '/user/addUser', data),
    deleteUser: (data) => this.trans('post', '/user/deleteUser', data),
    getAll: (data) => this.trans('get', '/user/getAll', data),
    getByUserNameForLike: (data) => this.trans('post', '/user/getByUserNameForLike', data),
    getSelfInfo: (data) => this.trans('get', '/user/getSelfInfo', data),
    updateSelfPassword: (data) => this.trans('post', '/user/updateSelfPassword', data),
    updateSelfUser: (data) => this.trans('post', '/user/updateSelfUser', data),
    updateUser: (data) => this.trans('post', '/user/updateUser', data),
  };

  public role = {
    addRole: (data) => this.trans('post', '/role/addRole', data),
    deleteRole: (data) => this.trans('post', '/role/deleteRole', data),
    getAll: (data) => this.trans('get', '/role/getAll', data),
    getByFactoryNo: (data) => this.trans('post', '/role/getByFactoryNo', data),
    getByRoleNameForLike: (data) => this.trans('post', '/role/getByRoleNameForLike', data),
    updateRole: (data) => this.trans('post', '/role/updateRole', data),
  };

  public device = {
    addDevice: (data) => this.trans('post', '/device/addDevice', data),
    addRecord: (data) => this.trans('post', '/device/addRecord', data),
    delDevice: (data) => this.trans('post', '/device/delDevice', data),
    downloadAlarmData: (data) => this.trans('post', '/device/downloadAlarmData', data),
    downloadData: (data) => this.trans('post', '/device/downloadData', data),
    downRecord: (data) => this.trans('get', '/device/downRecord', data),
    getAll: (data) => this.trans('get', '/device/getAll', data),
    setState: (data) => this.trans('post', '/device/setState', data),
    updateDevice: (data) => this.trans('post', '/device/updateDevice', data),
  };

  public model = {
    addModel: (data) => this.trans('post', '/model/addModel', data),
    delModel: (data) => this.trans('post', '/model/delModel', data),
    getAll: (data) => this.trans('get', '/model/getAll', data),
    getByDeviceType: (data) => this.trans('post', '/model/getByDeviceType', data),
    updateModel: (data) => this.trans('post', '/model/updateModel', data),
  };

  public modelInfo = {
    addModelInfo: (data) => this.trans('post', '/modelInfo/addModelInfo', data),
    delModelInfo: (data) => this.trans('post', '/modelInfo/delModelInfo', data),
    getAll: (data) => this.trans('post', '/modelInfo/getAll', data),
  };

  public probes = {
    addProbes: (data) => this.trans('post', '/probes/addProbes', data),
    delDevChannel: (data) => this.trans('post', '/probes/delDevChannel', data),
    getAll: (data) => this.trans('post', '/probes/getAll', data),
    updateDevChannel: (data) => this.trans('post', '/probes/updateDevChannel', data),
  };

  public probesModel = {
    addProbesModel: (data) => this.trans('post', '/probesModel/addProbesModel', data),
    delProbesModel: (data) => this.trans('post', '/probesModel/delProbesModel', data),
    getAll: (data) => this.trans('get', '/probesModel/getAll', data),
    updateProbesModel: (data) => this.trans('post', '/probesModel/updateProbesModel', data),
  };

  public topicModel = {
    addTopicModel: (data) => this.trans('post', '/topicModel/addTopicModel', data),
    delTopicModel: (data) => this.trans('post', '/topicModel/delTopicModel', data),
    getAll: (data) => this.trans('get', '/topicModel/getAll', data),
    updateTopic: (data) => this.trans('post', '/topicModel/updateTopic', data),
  };

  public topicModelInfo = {
    addTopicModelInfo: (data) => this.trans('post', '/topicModelInfo/addTopicModelInfo', data),
    delTopicModel: (data) => this.trans('post', '/topicModelInfo/delTopicModel', data),
    getAll: (data) => this.trans('post', '/topicModelInfo/getAll', data),
    updateTopicModelInfo: (data) => this.trans('post', '/topicModelInfo/updateTopicModelInfo', data),
  };

  public probesModelInfo = {
    addProbesModelInfo: (data) => this.trans('post', '/probesModelInfo/addProbesModelInfo', data),
    delProbesModelInfo: (data) => this.trans('post', '/probesModelInfo/delProbesModelInfo', data),
    getAll: (data) => this.trans('post', '/probesModelInfo/getAll', data),
    updateProbesModelInfo: (data) => this.trans('post', '/probesModelInfo/updateProbesModelInfo', data),
  };

  private trans(type, addr, data) {
    this.sendHttpReq(type, addr, data[0], data[1], data[2], data[3]);
  }

  private sendHttpReq(type, addr, reqB, next, error, complete) {
    let nextFunc;
    if (addr === '/login/dologin') {
      nextFunc = (data: any) => {
        next(data);
      };
    } else {
      nextFunc = (data: any) => {
        if (this.http.handleToken(data)) {
          next(data);
        } else {
          if (!this.tokenLoseflag) {
            this.message.error(this.translate.instant('loginOutValidityTips'));
            this.http.toLoginPage(2000);
            this.tokenLoseflag = 1;
            setTimeout(() => {
              this.tokenLoseflag = 0;
            }, 5000);
          }
        }
      };
    }
    if (!error) {
      error = (err) => {
        let data;
        if (err && err.error && err.error.status) {
          if (err.error.status === 401) {
            data = {code: 0, message: this.translate.instant('noLoginTips')};
            this.router.navigate(['/extra/login']);
          } else {
            data = {code: 0, message: this.translate.instant('wrongServerWithCode') + err.error.status};
          }
        } else {
          data = {code: 0, message: this.translate.instant('wrongServer')};
        }
        next(data);
      };
    }
    if (type === 'get') {
      this.http.get(this.url + addr, nextFunc, error, complete);
    } else {
      this.http.post(this.url + addr, reqB, nextFunc, error, complete);
    }
  }
}
